#!/usr/bin/env python

import re
import ROOT
import array

hdecay_re = re.compile("(?P<mass>\d+\.\d+)\s+\S+\s+\S+\s+\S+\s+\S+\s+\S+\s+(?P<width>\S+)")


def main():

    mass = []
    width = []

    fIN = open("br.sm2")
    for line in fIN:
        match = hdecay_re.search(line)
        if match:
            mass.append(float(match.group("mass")))
            width.append(float(match.group("width")))

    print(mass,width)

    plot(mass,width)

def plot(x,y):

    ROOT.gROOT.SetBatch(True)

    canvas = ROOT.TCanvas("canvas","",500,500)
    canvas.SetLeftMargin(0.14);
    canvas.SetRightMargin(0.06);
    canvas.cd()

    frame = ROOT.TH2F("frame","",2,95,155,2,0,0.02)
    frame.SetStats(0)
    frame.GetXaxis().SetTitle("m_{H} (GeV)")
    frame.GetYaxis().SetTitle("#Gamma_{tot} (GeV)")
    frame.GetYaxis().SetTitleOffset(1.8)
    frame.Draw()

    graph = ROOT.TGraph(len(x),array.array("f",x),array.array("f",y))
    graph.SetMarkerStyle(2)
    graph.SetMarkerSize(0.7)
    graph.Draw("P")

    canvas.Print("width.C")

if __name__ == "__main__":
    main()
