#!/usr/bin/env python

import os
import re
import sys
import subprocess
import ROOT
import array


width_re = re.compile("Higgs mass = *\S+ *, width = *(?P<width>\S+)")

canvas = 0

def main():

    higgsMasses = []
#    higgsMasses = [100,120,140,150]
    for m in range(100,151):
        higgsMasses.append(m)

    FHwidths = []
    HDwidths = []
    for mass in higgsMasses:
        FHwidth = execute("FHwidth.exe %i"%mass)
        HDwidth = execute("HDECAY/run %i"%mass)
        FHwidths.append(FHwidth)
        HDwidths.append(HDwidth)
        print("Mass, FH, HD",mass,FHwidth,HDwidth)

    plot(higgsMasses,FHwidths,HDwidths,"FeynHiggs 2.18.1","HDECAY 6.61")

def plot(x_in,y1_in,y2_in,title1,title2):

    ROOT.gROOT.SetBatch(True)

    N = len(x_in)
    x  = array.array("d",x_in)
    y1 = array.array("d",y1_in)
    y2 = array.array("d",y2_in)

    div = array.array("d")
    for i in range(N):
        div.append(y2_in[i]/y1_in[i])

    global canvas
    canvas = ROOT.TCanvas("canvas","",500,500)
    canvas.cd()
    a1 = 0.01
    b1 = 0.33
    a2 = 0.99
    b2 = 0.99
    graphpad = ROOT.TPad("graphpad","graphpad",a1,b1,a2,b2)
    graphpad.SetTopMargin(0.04)
    graphpad.SetRightMargin(0.04)
    graphpad.SetLeftMargin(0.14)
    graphpad.SetBottomMargin(0)
    graphpad.Draw()
    graphpad.cd()
    graphFrame = ROOT.TH2F("frame","",2,95,155,2,0,0.02)
    graphFrame.SetStats(0)
    graphFrame.GetXaxis().SetTitle("m_{H} (GeV)")
    graphFrame.GetXaxis().SetTitleSize(0.1)
    graphFrame.GetYaxis().SetTitleSize(0.05)
    graphFrame.GetYaxis().SetTitleOffset(1.2)
    graphFrame.GetYaxis().SetTitle("#Gamma_{tot} (GeV)")
    graphFrame.Draw()

    graph1 = ROOT.TGraph(N,x,y1)
    graph1.SetName("graph1")
    graph1.SetMarkerStyle(20)
    graph1.SetMarkerColor(ROOT.kRed)
    graph1.SetMarkerSize(0.5)
    graph1.Draw("P")

    graph2 = ROOT.TGraph(N,x,y2)
    graph2.SetName("graph2")
    graph2.SetMarkerStyle(21)
    graph2.SetMarkerSize(0.5)
    graph2.Draw("P")

    legend = ROOT.TLegend()
    legend.SetX1NDC(0.17)
    legend.SetY1NDC(0.78)
    legend.SetX2NDC(0.47)
    legend.SetY2NDC(0.90)
    legend.SetFillColor(0)
    legend.AddEntry(graph1,title1,"p")
    legend.AddEntry(graph2,title2,"p")
    legend.Draw()

    canvas.cd()

    a1 = 0.01
    b1 = 0.01
    a2 = 0.99
    b2 = 0.33
    ratiopad = ROOT.TPad("ratiopad","",a1,b1,a2,b2)
    ratiopad.SetTopMargin(0)
    ratiopad.SetRightMargin(0.04)
    ratiopad.SetLeftMargin(0.14)
    ratiopad.SetBottomMargin(0.3)
    ratiopad.SetFrameBorderMode(0)
    ratiopad.Draw()
    ratiopad.cd()
    ratioFrame = ROOT.TH2F("rframe","",2,graphFrame.GetXaxis().GetBinLowEdge(1),graphFrame.GetXaxis().GetBinLowEdge(graphFrame.GetNbinsX()+1),2,0.9,1.1)
    ratioFrame.SetStats(0)
    ratioFrame.GetXaxis().SetTitle("m_{H} (GeV)")
    titlescale = 2
    ratioFrame.GetXaxis().SetTitleSize(graphFrame.GetXaxis().GetTitleSize())
    ratioFrame.GetXaxis().SetLabelSize(titlescale*graphFrame.GetXaxis().GetLabelSize())
    ratioFrame.GetYaxis().SetTitleSize(titlescale*graphFrame.GetYaxis().GetTitleSize())
    ratioFrame.GetYaxis().SetLabelSize(titlescale*graphFrame.GetYaxis().GetLabelSize())
    ratioFrame.GetYaxis().SetTitleOffset(0.65)
    ratioFrame.GetYaxis().SetTitle("Ratio  ")
    ratioFrame.Draw()

    graphr = ROOT.TGraph(N,x,div)
    graphr.SetName("graphr")
    graphr.SetMarkerStyle(21)
    graphr.SetMarkerSize(0.5)
    graphr.Draw("P")

    canvas.cd()
    canvas.Print("comparisonplot.C")


def execute(cmd):
    args = cmd.split()
    tmpFile = subprocess.Popen(args, stdout=subprocess.PIPE).stdout
    for line in tmpFile:
        line = line.decode('utf-8')
        match = width_re.search(line)
        if match:
            return float(match.group("width"))
    return None


if __name__ == "__main__":
    main()
